/*
Copyright (c) 2015 - present Advanced Micro Devices, Inc. All rights reserved.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

#include "CUDA2HIP.h"

// Maps the names of CUDA SPARSE API functions to the corresponding HIP functions
const std::map<llvm::StringRef, hipCounter> CUDA_SPARSE_FUNCTION_MAP {
  // 5. cuSPARSE Management Function Reference
  {"cusparseCreate",                                    {"hipsparseCreate",                                    "", CONV_LIB_FUNC, API_SPARSE, 5}},
  {"cusparseDestroy",                                   {"hipsparseDestroy",                                   "", CONV_LIB_FUNC, API_SPARSE, 5}},
  {"cusparseGetPointerMode",                            {"hipsparseGetPointerMode",                            "", CONV_LIB_FUNC, API_SPARSE, 5}},
  {"cusparseGetVersion",                                {"hipsparseGetVersion",                                "", CONV_LIB_FUNC, API_SPARSE, 5}},
  {"cusparseSetPointerMode",                            {"hipsparseSetPointerMode",                            "", CONV_LIB_FUNC, API_SPARSE, 5}},
  {"cusparseSetStream",                                 {"hipsparseSetStream",                                 "", CONV_LIB_FUNC, API_SPARSE, 5}},
  {"cusparseGetStream",                                 {"hipsparseGetStream",                                 "", CONV_LIB_FUNC, API_SPARSE, 5}},

  // 6. cuSPARSE Helper Function Reference
  {"cusparseCreateSolveAnalysisInfo",                   {"hipsparseCreateSolveAnalysisInfo",                   "", CONV_LIB_FUNC, API_SPARSE, 6, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCreateHybMat",                              {"hipsparseCreateHybMat",                              "", CONV_LIB_FUNC, API_SPARSE, 6, DEPRECATED | REMOVED}},
  {"cusparseCreateMatDescr",                            {"hipsparseCreateMatDescr",                            "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseDestroySolveAnalysisInfo",                  {"hipsparseDestroySolveAnalysisInfo",                  "", CONV_LIB_FUNC, API_SPARSE, 6, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDestroyHybMat",                             {"hipsparseDestroyHybMat",                             "", CONV_LIB_FUNC, API_SPARSE, 6, DEPRECATED | REMOVED}},
  {"cusparseDestroyMatDescr",                           {"hipsparseDestroyMatDescr",                           "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseGetLevelInfo",                              {"hipsparseGetLevelInfo",                              "", CONV_LIB_FUNC, API_SPARSE, 6, HIP_UNSUPPORTED | REMOVED}},
  {"cusparseGetMatDiagType",                            {"hipsparseGetMatDiagType",                            "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseGetMatFillMode",                            {"hipsparseGetMatFillMode",                            "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseGetMatIndexBase",                           {"hipsparseGetMatIndexBase",                           "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseGetMatType",                                {"hipsparseGetMatType",                                "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseSetMatDiagType",                            {"hipsparseSetMatDiagType",                            "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseSetMatFillMode",                            {"hipsparseSetMatFillMode",                            "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseSetMatIndexBase",                           {"hipsparseSetMatIndexBase",                           "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseSetMatType",                                {"hipsparseSetMatType",                                "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseCreateCsrsv2Info",                          {"hipsparseCreateCsrsv2Info",                          "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseDestroyCsrsv2Info",                         {"hipsparseDestroyCsrsv2Info",                         "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseCreateCsrsm2Info",                          {"hipsparseCreateCsrsm2Info",                          "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseDestroyCsrsm2Info",                         {"hipsparseDestroyCsrsm2Info",                         "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseCreateCsric02Info",                         {"hipsparseCreateCsric02Info",                         "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseDestroyCsric02Info",                        {"hipsparseDestroyCsric02Info",                        "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseCreateCsrilu02Info",                        {"hipsparseCreateCsrilu02Info",                        "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseDestroyCsrilu02Info",                       {"hipsparseDestroyCsrilu02Info",                       "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseCreateBsrsv2Info",                          {"hipsparseCreateBsrsv2Info",                          "", CONV_LIB_FUNC, API_SPARSE, 6, HIP_UNSUPPORTED}},
  {"cusparseDestroyBsrsv2Info",                         {"hipsparseDestroyBsrsv2Info",                         "", CONV_LIB_FUNC, API_SPARSE, 6, HIP_UNSUPPORTED}},
  {"cusparseCreateBsrsm2Info",                          {"hipsparseCreateBsrsm2Info",                          "", CONV_LIB_FUNC, API_SPARSE, 6, HIP_UNSUPPORTED}},
  {"cusparseDestroyBsrsm2Info",                         {"hipsparseDestroyBsrsm2Info",                         "", CONV_LIB_FUNC, API_SPARSE, 6, HIP_UNSUPPORTED}},
  {"cusparseCreateBsric02Info",                         {"hipsparseCreateBsric02Info",                         "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseDestroyBsric02Info",                        {"hipsparseDestroyBsric02Info",                        "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseCreateBsrilu02Info",                        {"hipsparseCreateBsrilu02Info",                        "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseDestroyBsrilu02Info",                       {"hipsparseDestroyBsrilu02Info",                       "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseCreateCsrgemm2Info",                        {"hipsparseCreateCsrgemm2Info",                        "", CONV_LIB_FUNC, API_SPARSE, 6, DEPRECATED}},
  {"cusparseDestroyCsrgemm2Info",                       {"hipsparseDestroyCsrgemm2Info",                       "", CONV_LIB_FUNC, API_SPARSE, 6, DEPRECATED}},
  {"cusparseCreatePruneInfo",                           {"hipsparseCreatePruneInfo",                           "", CONV_LIB_FUNC, API_SPARSE, 6}},
  {"cusparseDestroyPruneInfo",                          {"hipsparseDestroyPruneInfo",                          "", CONV_LIB_FUNC, API_SPARSE, 6}},

  // 7. cuSPARSE Level 1 Function Reference
  {"cusparseSaxpyi",                                    {"hipsparseSaxpyi",                                    "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseDaxpyi",                                    {"hipsparseDaxpyi",                                    "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseCaxpyi",                                    {"hipsparseCaxpyi",                                    "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseZaxpyi",                                    {"hipsparseZaxpyi",                                    "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},

  {"cusparseSdoti",                                     {"hipsparseSdoti",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED | REMOVED}},
  {"cusparseDdoti",                                     {"hipsparseDdoti",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED | REMOVED}},
  {"cusparseCdoti",                                     {"hipsparseCdoti",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED | REMOVED}},
  {"cusparseZdoti",                                     {"hipsparseZdoti",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED | REMOVED}},

  {"cusparseCdotci",                                    {"hipsparseCdotci",                                    "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED | REMOVED}},
  {"cusparseZdotci",                                    {"hipsparseZdotci",                                    "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED | REMOVED}},

  {"cusparseSgthr",                                     {"hipsparseSgthr",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseDgthr",                                     {"hipsparseDgthr",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseCgthr",                                     {"hipsparseCgthr",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseZgthr",                                     {"hipsparseZgthr",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},

  {"cusparseSgthrz",                                    {"hipsparseSgthrz",                                    "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseDgthrz",                                    {"hipsparseDgthrz",                                    "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseCgthrz",                                    {"hipsparseCgthrz",                                    "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseZgthrz",                                    {"hipsparseZgthrz",                                    "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},

  {"cusparseSroti",                                     {"hipsparseSroti",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseDroti",                                     {"hipsparseDroti",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},

  {"cusparseSsctr",                                     {"hipsparseSsctr",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseDsctr",                                     {"hipsparseDsctr",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseCsctr",                                     {"hipsparseCsctr",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},
  {"cusparseZsctr",                                     {"hipsparseZsctr",                                     "", CONV_LIB_FUNC, API_SPARSE, 7, DEPRECATED}},

  // 8. cuSPARSE Level 2 Function Reference
  {"cusparseSbsrmv",                                    {"hipsparseSbsrmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseDbsrmv",                                    {"hipsparseDbsrmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseCbsrmv",                                    {"hipsparseCbsrmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseZbsrmv",                                    {"hipsparseZbsrmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8}},

  {"cusparseSbsrxmv",                                   {"hipsparseSbsrxmv",                                   "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},
  {"cusparseDbsrxmv",                                   {"hipsparseDbsrxmv",                                   "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},
  {"cusparseCbsrxmv",                                   {"hipsparseCbsrxmv",                                   "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},
  {"cusparseZbsrxmv",                                   {"hipsparseZbsrxmv",                                   "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},

  {"cusparseScsrmv",                                    {"hipsparseScsrmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, DEPRECATED | REMOVED}},
  {"cusparseDcsrmv",                                    {"hipsparseDcsrmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, DEPRECATED | REMOVED}},
  {"cusparseCcsrmv",                                    {"hipsparseCcsrmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, DEPRECATED | REMOVED}},
  {"cusparseZcsrmv",                                    {"hipsparseZcsrmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, DEPRECATED | REMOVED}},

  {"cusparseCsrmvEx",                                   {"hipsparseCsrmvEx",                                   "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},
  {"cusparseCsrmvEx_bufferSize",                        {"hipsparseCsrmvEx_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},

  {"cusparseScsrmv_mp",                                 {"hipsparseScsrmv_mp",                                 "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDcsrmv_mp",                                 {"hipsparseDcsrmv_mp",                                 "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCcsrmv_mp",                                 {"hipsparseCcsrmv_mp",                                 "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZcsrmv_mp",                                 {"hipsparseZcsrmv_mp",                                 "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseSgemvi",                                    {"hipsparseSgemvi",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},
  {"cusparseDgemvi",                                    {"hipsparseDgemvi",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},
  {"cusparseCgemvi",                                    {"hipsparseCgemvi",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},
  {"cusparseZgemvi",                                    {"hipsparseZgemvi",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},

  {"cusparseSgemvi_bufferSize",                         {"hipsparseSgemvi_bufferSize",                         "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},
  {"cusparseDgemvi_bufferSize",                         {"hipsparseDgemvi_bufferSize",                         "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},
  {"cusparseCgemvi_bufferSize",                         {"hipsparseCgemvi_bufferSize",                         "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},
  {"cusparseZgemvi_bufferSize",                         {"hipsparseZgemvi_bufferSize",                         "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED}},

  {"cusparseSbsrsv2_bufferSize",                        {"hipsparseSbsrsv2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseSbsrsv2_bufferSizeExt",                     {"hipsparseSbsrsv2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseDbsrsv2_bufferSize",                        {"hipsparseDbsrsv2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseDbsrsv2_bufferSizeExt",                     {"hipsparseDbsrsv2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseCbsrsv2_bufferSize",                        {"hipsparseCbsrsv2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseCbsrsv2_bufferSizeExt",                     {"hipsparseCbsrsv2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseZbsrsv2_bufferSize",                        {"hipsparseZbsrsv2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseZbsrsv2_bufferSizeExt",                     {"hipsparseZbsrsv2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 8}},

  {"cusparseSbsrsv2_analysis",                          {"hipsparseSbsrsv2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseDbsrsv2_analysis",                          {"hipsparseDbsrsv2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseCbsrsv2_analysis",                          {"hipsparseCbsrsv2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseZbsrsv2_analysis",                          {"hipsparseZbsrsv2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 8}},

  {"cusparseScsrsv_solve",                              {"hipsparseScsrsv_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDcsrsv_solve",                              {"hipsparseDcsrsv_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCcsrsv_solve",                              {"hipsparseCcsrsv_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZcsrsv_solve",                              {"hipsparseZcsrsv_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseSbsrsv2_solve",                             {"hipsparseSbsrsv2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseDbsrsv2_solve",                             {"hipsparseDbsrsv2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseCbsrsv2_solve",                             {"hipsparseCbsrsv2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseZbsrsv2_solve",                             {"hipsparseZbsrsv2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseXbsrsv2_zeroPivot",                         {"hipsparseXbsrsv2_zeroPivot",                         "", CONV_LIB_FUNC, API_SPARSE, 8}},

  {"cusparseScsrsv_analysis",                           {"hipsparseScsrsv_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDcsrsv_analysis",                           {"hipsparseDcsrsv_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCcsrsv_analysis",                           {"hipsparseCcsrsv_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZcsrsv_analysis",                           {"hipsparseZcsrsv_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseCsrsv_analysisEx",                          {"hipsparseCsrsv_analysisEx",                          "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCsrsv_solveEx",                             {"hipsparseCsrsv_solveEx",                             "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseScsrsv2_bufferSize",                        {"hipsparseScsrsv2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseScsrsv2_bufferSizeExt",                     {"hipsparseScsrsv2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseDcsrsv2_bufferSize",                        {"hipsparseDcsrsv2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseDcsrsv2_bufferSizeExt",                     {"hipsparseDcsrsv2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseCcsrsv2_bufferSize",                        {"hipsparseCcsrsv2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseCcsrsv2_bufferSizeExt",                     {"hipsparseCcsrsv2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseZcsrsv2_bufferSize",                        {"hipsparseZcsrsv2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseZcsrsv2_bufferSizeExt",                     {"hipsparseZcsrsv2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 8}},

  {"cusparseScsrsv2_analysis",                          {"hipsparseScsrsv2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseDcsrsv2_analysis",                          {"hipsparseDcsrsv2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseCcsrsv2_analysis",                          {"hipsparseCcsrsv2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseZcsrsv2_analysis",                          {"hipsparseZcsrsv2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 8}},

  {"cusparseScsrsv2_solve",                             {"hipsparseScsrsv2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseDcsrsv2_solve",                             {"hipsparseDcsrsv2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseCcsrsv2_solve",                             {"hipsparseCcsrsv2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseZcsrsv2_solve",                             {"hipsparseZcsrsv2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 8}},
  {"cusparseXcsrsv2_zeroPivot",                         {"hipsparseXcsrsv2_zeroPivot",                         "", CONV_LIB_FUNC, API_SPARSE, 8}},

  {"cusparseShybmv",                                    {"hipsparseShybmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, DEPRECATED | REMOVED}},
  {"cusparseDhybmv",                                    {"hipsparseDhybmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, DEPRECATED | REMOVED}},
  {"cusparseChybmv",                                    {"hipsparseChybmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, DEPRECATED | REMOVED}},
  {"cusparseZhybmv",                                    {"hipsparseZhybmv",                                    "", CONV_LIB_FUNC, API_SPARSE, 8, DEPRECATED | REMOVED}},

  {"cusparseShybsv_analysis",                           {"hipsparseShybsv_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDhybsv_analysis",                           {"hipsparseDhybsv_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseChybsv_analysis",                           {"hipsparseChybsv_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZhybsv_analysis",                           {"hipsparseZhybsv_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseShybsv_solve",                              {"hipsparseShybsv_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDhybsv_solve",                              {"hipsparseDhybsv_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseChybsv_solve",                              {"hipsparseChybsv_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZhybsv_solve",                              {"hipsparseZhybsv_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 8, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  // 9. cuSPARSE Level 3 Function Reference
  {"cusparseScsrmm",                                    {"hipsparseScsrmm",                                    "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},
  {"cusparseDcsrmm",                                    {"hipsparseDcsrmm",                                    "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},
  {"cusparseCcsrmm",                                    {"hipsparseCcsrmm",                                    "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},
  {"cusparseZcsrmm",                                    {"hipsparseZcsrmm",                                    "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},

  {"cusparseScsrmm2",                                   {"hipsparseScsrmm2",                                   "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},
  {"cusparseDcsrmm2",                                   {"hipsparseDcsrmm2",                                   "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},
  {"cusparseCcsrmm2",                                   {"hipsparseCcsrmm2",                                   "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},
  {"cusparseZcsrmm2",                                   {"hipsparseZcsrmm2",                                   "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},

  {"cusparseScsrsm_analysis",                           {"hipsparseScsrsm_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDcsrsm_analysis",                           {"hipsparseDcsrsm_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCcsrsm_analysis",                           {"hipsparseCcsrsm_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZcsrsm_analysis",                           {"hipsparseZcsrsm_analysis",                           "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseScsrsm_solve",                              {"hipsparseScsrsm_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},
  {"cusparseDcsrsm_solve",                              {"hipsparseDcsrsm_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},
  {"cusparseCcsrsm_solve",                              {"hipsparseCcsrsm_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},
  {"cusparseZcsrsm_solve",                              {"hipsparseZcsrsm_solve",                              "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED | REMOVED}},

  {"cusparseScsrsm2_bufferSizeExt",                     {"hipsparseScsrsm2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseDcsrsm2_bufferSizeExt",                     {"hipsparseDcsrsm2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseCcsrsm2_bufferSizeExt",                     {"hipsparseCcsrsm2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseZcsrsm2_bufferSizeExt",                     {"hipsparseZcsrsm2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 9}},

  {"cusparseScsrsm2_analysis",                          {"hipsparseScsrsm2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseDcsrsm2_analysis",                          {"hipsparseDcsrsm2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseCcsrsm2_analysis",                          {"hipsparseCcsrsm2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseZcsrsm2_analysis",                          {"hipsparseZcsrsm2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 9}},

  {"cusparseScsrsm2_solve",                             {"hipsparseScsrsm2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseDcsrsm2_solve",                             {"hipsparseDcsrsm2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseCcsrsm2_solve",                             {"hipsparseCcsrsm2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseZcsrsm2_solve",                             {"hipsparseZcsrsm2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseXcsrsm2_zeroPivot",                         {"hipsparseXcsrsm2_zeroPivot",                         "", CONV_LIB_FUNC, API_SPARSE, 9}},

  {"cusparseSbsrmm",                                    {"hipsparseSbsrmm",                                    "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseDbsrmm",                                    {"hipsparseDbsrmm",                                    "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseCbsrmm",                                    {"hipsparseCbsrmm",                                    "", CONV_LIB_FUNC, API_SPARSE, 9}},
  {"cusparseZbsrmm",                                    {"hipsparseZbsrmm",                                    "", CONV_LIB_FUNC, API_SPARSE, 9}},

  {"cusparseSbsrsm2_bufferSize",                        {"hipsparseCbsrsm2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseSbsrsm2_bufferSizeExt",                     {"hipsparseCbsrsm2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseDbsrsm2_bufferSize",                        {"hipsparseDbsrsm2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseDbsrsm2_bufferSizeExt",                     {"hipsparseDbsrsm2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseCbsrsm2_bufferSize",                        {"hipsparseCbsrsm2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseCbsrsm2_bufferSizeExt",                     {"hipsparseCbsrsm2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseZbsrsm2_bufferSize",                        {"hipsparseZbsrsm2_bufferSize",                        "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseZbsrsm2_bufferSizeExt",                     {"hipsparseZbsrsm2_bufferSizeExt",                     "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},

  {"cusparseSbsrsm2_analysis",                          {"hipsparseSbsrsm2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseDbsrsm2_analysis",                          {"hipsparseDbsrsm2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseCbsrsm2_analysis",                          {"hipsparseCbsrsm2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseZbsrsm2_analysis",                          {"hipsparseZbsrsm2_analysis",                          "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},

  {"cusparseSbsrsm2_solve",                             {"hipsparseSbsrsm2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseDbsrsm2_solve",                             {"hipsparseDbsrsm2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseCbsrsm2_solve",                             {"hipsparseCbsrsm2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseZbsrsm2_solve",                             {"hipsparseZbsrsm2_solve",                             "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},
  {"cusparseXbsrsm2_zeroPivot",                         {"hipsparseXbsrsm2_zeroPivot",                         "", CONV_LIB_FUNC, API_SPARSE, 9, HIP_UNSUPPORTED}},

  {"cusparseSgemmi",                                    {"hipsparseSgemmi",                                    "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED}},
  {"cusparseDgemmi",                                    {"hipsparseDgemmi",                                    "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED}},
  {"cusparseCgemmi",                                    {"hipsparseCgemmi",                                    "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED}},
  {"cusparseZgemmi",                                    {"hipsparseZgemmi",                                    "", CONV_LIB_FUNC, API_SPARSE, 9, DEPRECATED}},

  // 10. cuSPARSE Extra Function Reference
  {"cusparseScsrgeam",                                  {"hipsparseScsrgeam",                                  "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED | REMOVED}},
  {"cusparseDcsrgeam",                                  {"hipsparseDcsrgeam",                                  "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED | REMOVED}},
  {"cusparseCcsrgeam",                                  {"hipsparseCcsrgeam",                                  "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED | REMOVED}},
  {"cusparseZcsrgeam",                                  {"hipsparseZcsrgeam",                                  "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED | REMOVED}},
  {"cusparseXcsrgeamNnz",                               {"hipsparseXcsrgeamNnz",                               "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED | REMOVED}},

  {"cusparseScsrgeam2",                                 {"hipsparseScsrgeam2",                                 "", CONV_LIB_FUNC, API_SPARSE, 10}},
  {"cusparseDcsrgeam2",                                 {"hipsparseDcsrgeam2",                                 "", CONV_LIB_FUNC, API_SPARSE, 10}},
  {"cusparseCcsrgeam2",                                 {"hipsparseCcsrgeam2",                                 "", CONV_LIB_FUNC, API_SPARSE, 10}},
  {"cusparseZcsrgeam2",                                 {"hipsparseZcsrgeam2",                                 "", CONV_LIB_FUNC, API_SPARSE, 10}},
  {"cusparseXcsrgeam2Nnz",                              {"hipsparseXcsrgeam2Nnz",                              "", CONV_LIB_FUNC, API_SPARSE, 10}},

  {"cusparseScsrgeam2_bufferSizeExt",                   {"hipsparseScsrgeam2_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 10}},
  {"cusparseDcsrgeam2_bufferSizeExt",                   {"hipsparseDcsrgeam2_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 10}},
  {"cusparseCcsrgeam2_bufferSizeExt",                   {"hipsparseCcsrgeam2_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 10}},
  {"cusparseZcsrgeam2_bufferSizeExt",                   {"hipsparseZcsrgeam2_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 10}},

  {"cusparseScsrgemm",                                  {"hipsparseScsrgemm",                                  "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED | REMOVED}},
  {"cusparseDcsrgemm",                                  {"hipsparseDcsrgemm",                                  "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED | REMOVED}},
  {"cusparseCcsrgemm",                                  {"hipsparseCcsrgemm",                                  "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED | REMOVED}},
  {"cusparseZcsrgemm",                                  {"hipsparseZcsrgemm",                                  "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED | REMOVED}},
  {"cusparseXcsrgemmNnz",                               {"hipsparseXcsrgemmNnz",                               "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED | REMOVED}},

  {"cusparseScsrgemm2",                                 {"hipsparseScsrgemm2",                                 "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED}},
  {"cusparseDcsrgemm2",                                 {"hipsparseDcsrgemm2",                                 "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED}},
  {"cusparseCcsrgemm2",                                 {"hipsparseCcsrgemm2",                                 "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED}},
  {"cusparseZcsrgemm2",                                 {"hipsparseZcsrgemm2",                                 "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED}},
  {"cusparseXcsrgemm2Nnz",                              {"hipsparseXcsrgemm2Nnz",                              "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED}},

  {"cusparseScsrgemm2_bufferSizeExt",                   {"hipsparseScsrgemm2_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED}},
  {"cusparseDcsrgemm2_bufferSizeExt",                   {"hipsparseDcsrgemm2_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED}},
  {"cusparseCcsrgemm2_bufferSizeExt",                   {"hipsparseCcsrgemm2_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED}},
  {"cusparseZcsrgemm2_bufferSizeExt",                   {"hipsparseZcsrgemm2_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 10, DEPRECATED}},

  // 11. cuSPARSE Preconditioners Reference
  // 11.1. Incomplete Cholesky Factorization : level 0
  {"cusparseScsric0",                                   {"hipsparseScsric0",                                   "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDcsric0",                                   {"hipsparseDcsric0",                                   "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCcsric0",                                   {"hipsparseCcsric0",                                   "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZcsric0",                                   {"hipsparseZcsric0",                                   "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseScsric02_bufferSize",                       {"hipsparseScsric02_bufferSize",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseScsric02_bufferSizeExt",                    {"hipsparseScsric02_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDcsric02_bufferSize",                       {"hipsparseDcsric02_bufferSize",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDcsric02_bufferSizeExt",                    {"hipsparseDcsric02_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCcsric02_bufferSize",                       {"hipsparseCcsric02_bufferSize",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCcsric02_bufferSizeExt",                    {"hipsparseCcsric02_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZcsric02_bufferSize",                       {"hipsparseZcsric02_bufferSize",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZcsric02_bufferSizeExt",                    {"hipsparseZcsric02_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},

  {"cusparseScsric02_analysis",                         {"hipsparseScsric02_analysis",                         "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDcsric02_analysis",                         {"hipsparseDcsric02_analysis",                         "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCcsric02_analysis",                         {"hipsparseCcsric02_analysis",                         "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZcsric02_analysis",                         {"hipsparseZcsric02_analysis",                         "", CONV_LIB_FUNC, API_SPARSE, 11}},

  {"cusparseScsric02",                                  {"hipsparseScsric02",                                  "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDcsric02",                                  {"hipsparseDcsric02",                                  "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCcsric02",                                  {"hipsparseCcsric02",                                  "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZcsric02",                                  {"hipsparseZcsric02",                                  "", CONV_LIB_FUNC, API_SPARSE, 11}},

  {"cusparseXcsric02_zeroPivot",                        {"hipsparseXcsric02_zeroPivot",                        "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseSbsric02_bufferSize",                       {"hipsparseSbsric02_bufferSize",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseSbsric02_bufferSizeExt",                    {"hipsparseSbsric02_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDbsric02_bufferSize",                       {"hipsparseDbsric02_bufferSize",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDbsric02_bufferSizeExt",                    {"hipsparseDbsric02_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCbsric02_bufferSize",                       {"hipsparseCbsric02_bufferSize",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCbsric02_bufferSizeExt",                    {"hipsparseCbsric02_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZbsric02_bufferSize",                       {"hipsparseZbsric02_bufferSize",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZbsric02_bufferSizeExt",                    {"hipsparseZbsric02_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  {"cusparseSbsric02_analysis",                         {"hipsparseSbsric02_analysis",                         "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDbsric02_analysis",                         {"hipsparseDbsric02_analysis",                         "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCbsric02_analysis",                         {"hipsparseCbsric02_analysis",                         "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZbsric02_analysis",                         {"hipsparseZbsric02_analysis",                         "", CONV_LIB_FUNC, API_SPARSE, 11}},

  {"cusparseSbsric02",                                  {"hipsparseSbsric02",                                  "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDbsric02",                                  {"hipsparseDbsric02",                                  "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCbsric02",                                  {"hipsparseCbsric02",                                  "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZbsric02",                                  {"hipsparseZbsric02",                                  "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseXbsric02_zeroPivot",                        {"hipsparseXbsric02_zeroPivot",                        "", CONV_LIB_FUNC, API_SPARSE, 11}},

  // 11.2. Incomplete LU Factorization: level 0
  {"cusparseScsrilu0",                                  {"hipsparseScsrilu0",                                  "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDcsrilu0",                                  {"hipsparseDcsrilu0",                                  "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCcsrilu0",                                  {"hipsparseCcsrilu0",                                  "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZcsrilu0",                                  {"hipsparseZcsrilu0",                                  "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCsrilu0Ex",                                 {"hipsparseCsrilu0Ex",                                 "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseScsrilu02_numericBoost",                    {"hipsparseScsrilu02_numericBoost",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDcsrilu02_numericBoost",                    {"hipsparseDcsrilu02_numericBoost",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCcsrilu02_numericBoost",                    {"hipsparseCcsrilu02_numericBoost",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZcsrilu02_numericBoost",                    {"hipsparseZcsrilu02_numericBoost",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseXcsrilu02_zeroPivot",                       {"hipsparseXcsrilu02_zeroPivot",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},

  {"cusparseScsrilu02_bufferSize",                      {"hipsparseScsrilu02_bufferSize",                      "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseScsrilu02_bufferSizeExt",                   {"hipsparseScsrilu02_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDcsrilu02_bufferSize",                      {"hipsparseDcsrilu02_bufferSize",                      "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDcsrilu02_bufferSizeExt",                   {"hipsparseDcsrilu02_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCcsrilu02_bufferSize",                      {"hipsparseCcsrilu02_bufferSize",                      "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCcsrilu02_bufferSizeExt",                   {"hipsparseCcsrilu02_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZcsrilu02_bufferSize",                      {"hipsparseZcsrilu02_bufferSize",                      "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZcsrilu02_bufferSizeExt",                   {"hipsparseZcsrilu02_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 11}},

  {"cusparseScsrilu02_analysis",                        {"hipsparseScsrilu02_analysis",                        "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDcsrilu02_analysis",                        {"hipsparseDcsrilu02_analysis",                        "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCcsrilu02_analysis",                        {"hipsparseCcsrilu02_analysis",                        "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZcsrilu02_analysis",                        {"hipsparseZcsrilu02_analysis",                        "", CONV_LIB_FUNC, API_SPARSE, 11}},

  {"cusparseScsrilu02",                                 {"hipsparseScsrilu02",                                 "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDcsrilu02",                                 {"hipsparseDcsrilu02",                                 "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCcsrilu02",                                 {"hipsparseCcsrilu02",                                 "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZcsrilu02",                                 {"hipsparseZcsrilu02",                                 "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseXbsric02_zeroPivot",                        {"hipsparseXcsrilu02_zeroPivot",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},

  {"cusparseSbsrilu02_numericBoost",                    {"hipsparseSbsrilu02_numericBoost",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDbsrilu02_numericBoost",                    {"hipsparseDbsrilu02_numericBoost",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCbsrilu02_numericBoost",                    {"hipsparseCbsrilu02_numericBoost",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZbsrilu02_numericBoost",                    {"hipsparseZbsrilu02_numericBoost",                    "", CONV_LIB_FUNC, API_SPARSE, 11}},

  {"cusparseSbsrilu02_bufferSize",                      {"hipsparseSbsrilu02_bufferSize",                      "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseSbsrilu02_bufferSizeExt",                   {"hipsparseSbsrilu02_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDbsrilu02_bufferSize",                      {"hipsparseDbsrilu02_bufferSize",                      "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDbsrilu02_bufferSizeExt",                   {"hipsparseDbsrilu02_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCbsrilu02_bufferSize",                      {"hipsparseCbsrilu02_bufferSize",                      "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCbsrilu02_bufferSizeExt",                   {"hipsparseCbsrilu02_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZbsrilu02_bufferSize",                      {"hipsparseZbsrilu02_bufferSize",                      "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZbsrilu02_bufferSizeExt",                   {"hipsparseZbsrilu02_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  {"cusparseSbsrilu02_analysis",                        {"hipsparseSbsrilu02_analysis",                        "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDbsrilu02_analysis",                        {"hipsparseDbsrilu02_analysis",                        "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCbsrilu02_analysis",                        {"hipsparseCbsrilu02_analysis",                        "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZbsrilu02_analysis",                        {"hipsparseZbsrilu02_analysis",                        "", CONV_LIB_FUNC, API_SPARSE, 11}},

  {"cusparseSbsrilu02",                                 {"hipsparseSbsrilu02",                                 "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseDbsrilu02",                                 {"hipsparseDbsrilu02",                                 "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseCbsrilu02",                                 {"hipsparseCbsrilu02",                                 "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseZbsrilu02",                                 {"hipsparseZbsrilu02",                                 "", CONV_LIB_FUNC, API_SPARSE, 11}},
  {"cusparseXbsrilu02_zeroPivot",                       {"hipsparseXbsrilu02_zeroPivot",                       "", CONV_LIB_FUNC, API_SPARSE, 11}},

  // 11.3. Tridiagonal Solve
  {"cusparseSgtsv",                                     {"hipsparseSgtsv",                                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDgtsv",                                     {"hipsparseDgtsv",                                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCgtsv",                                     {"hipsparseCgtsv",                                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZgtsv",                                     {"hipsparseZgtsv",                                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseSgtsv_nopivot",                             {"hipsparseSgtsv_nopivot",                             "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDgtsv_nopivot",                             {"hipsparseDgtsv_nopivot",                             "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCgtsv_nopivot",                             {"hipsparseCgtsv_nopivot",                             "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZgtsv_nopivot",                             {"hipsparseZgtsv_nopivot",                             "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseSgtsv2_bufferSizeExt",                      {"hipsparseSgtsv2_bufferSizeExt",                      "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDgtsv2_bufferSizeExt",                      {"hipsparseDgtsv2_bufferSizeExt",                      "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCgtsv2_bufferSizeExt",                      {"hipsparseCgtsv2_bufferSizeExt",                      "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZgtsv2_bufferSizeExt",                      {"hipsparseZgtsv2_bufferSizeExt",                      "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  {"cusparseSgtsv2",                                    {"hipsparseSgtsv2",                                    "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDgtsv2",                                    {"hipsparseDgtsv2",                                    "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCgtsv2",                                    {"hipsparseCgtsv2",                                    "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZgtsv2",                                    {"hipsparseZgtsv2",                                    "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  {"cusparseSgtsv2_nopivot_bufferSizeExt",              {"hipsparseSgtsv2_nopivot_bufferSizeExt",              "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDgtsv2_nopivot_bufferSizeExt",              {"hipsparseDgtsv2_nopivot_bufferSizeExt",              "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCgtsv2_nopivot_bufferSizeExt",              {"hipsparseCgtsv2_nopivot_bufferSizeExt",              "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZgtsv2_nopivot_bufferSizeExt",              {"hipsparseZgtsv2_nopivot_bufferSizeExt",              "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  {"cusparseSgtsv2_nopivot",                            {"hipsparseSgtsv2_nopivot",                            "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDgtsv2_nopivot",                            {"hipsparseDgtsv2_nopivot",                            "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCgtsv2_nopivot",                            {"hipsparseCgtsv2_nopivot",                            "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZgtsv2_nopivot",                            {"hipsparseZgtsv2_nopivot",                            "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  // 11.4. Batched Tridiagonal Solve
  {"cusparseSgtsvStridedBatch",                         {"hipsparseSgtsvStridedBatch",                         "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDgtsvStridedBatch",                         {"hipsparseDgtsvStridedBatch",                         "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCgtsvStridedBatch",                         {"hipsparseCgtsvStridedBatch",                         "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZgtsvStridedBatch",                         {"hipsparseZgtsvStridedBatch",                         "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseSgtsv2StridedBatch_bufferSizeExt",          {"hipsparseSgtsv2StridedBatch_bufferSizeExt",          "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDgtsv2StridedBatch_bufferSizeExt",          {"hipsparseDgtsv2StridedBatch_bufferSizeExt",          "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCgtsv2StridedBatch_bufferSizeExt",          {"hipsparseCgtsv2StridedBatch_bufferSizeExt",          "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZgtsv2StridedBatch_bufferSizeExt",          {"hipsparseZgtsv2StridedBatch_bufferSizeExt",          "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  {"cusparseSgtsv2StridedBatch",                        {"hipsparseSgtsv2StridedBatch",                        "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDgtsv2StridedBatch",                        {"hipsparseDgtsv2StridedBatch",                        "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCgtsv2StridedBatch",                        {"hipsparseCgtsv2StridedBatch",                        "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZgtsv2StridedBatch",                        {"hipsparseZgtsv2StridedBatch",                        "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  {"cusparseSgtsvInterleavedBatch_bufferSizeExt",       {"hipsparseSgtsvInterleavedBatch_bufferSizeExt",       "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDgtsvInterleavedBatch_bufferSizeExt",       {"hipsparseDgtsvInterleavedBatch_bufferSizeExt",       "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCgtsvInterleavedBatch_bufferSizeExt",       {"hipsparseCgtsvInterleavedBatch_bufferSizeExt",       "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZgtsvInterleavedBatch_bufferSizeExt",       {"hipsparseZgtsvInterleavedBatch_bufferSizeExt",       "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  {"cusparseSgtsvInterleavedBatch",                     {"hipsparseSgtsvInterleavedBatch",                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDgtsvInterleavedBatch",                     {"hipsparseDgtsvInterleavedBatch",                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCgtsvInterleavedBatch",                     {"hipsparseCgtsvInterleavedBatch",                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZgtsvInterleavedBatch",                     {"hipsparseZgtsvInterleavedBatch",                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  // 11.5. Batched Pentadiagonal Solve
  {"cusparseSgpsvInterleavedBatch_bufferSizeExt",       {"hipsparseSgpsvInterleavedBatch_bufferSizeExt",       "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDgpsvInterleavedBatch_bufferSizeExt",       {"hipsparseDgpsvInterleavedBatch_bufferSizeExt",       "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCgpsvInterleavedBatch_bufferSizeExt",       {"hipsparseCgpsvInterleavedBatch_bufferSizeExt",       "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZgpsvInterleavedBatch_bufferSizeExt",       {"hipsparseZgpsvInterleavedBatch_bufferSizeExt",       "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  {"cusparseSgpsvInterleavedBatch",                     {"hipsparseSgpsvInterleavedBatch",                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseDgpsvInterleavedBatch",                     {"hipsparseDgpsvInterleavedBatch",                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseCgpsvInterleavedBatch",                     {"hipsparseCgpsvInterleavedBatch",                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},
  {"cusparseZgpsvInterleavedBatch",                     {"hipsparseZgpsvInterleavedBatch",                     "", CONV_LIB_FUNC, API_SPARSE, 11, HIP_UNSUPPORTED}},

  // 12. cuSPARSE Matrix Reorderings Reference
  {"cusparseScsrcolor",                                 {"hipsparseScsrcolor",                                 "", CONV_LIB_FUNC, API_SPARSE, 12, HIP_UNSUPPORTED}},
  {"cusparseDcsrcolor",                                 {"hipsparseDcsrcolor",                                 "", CONV_LIB_FUNC, API_SPARSE, 12, HIP_UNSUPPORTED}},
  {"cusparseCcsrcolor",                                 {"hipsparseCcsrcolor",                                 "", CONV_LIB_FUNC, API_SPARSE, 12, HIP_UNSUPPORTED}},
  {"cusparseZcsrcolor",                                 {"hipsparseZcsrcolor",                                 "", CONV_LIB_FUNC, API_SPARSE, 12, HIP_UNSUPPORTED}},

  // 13. cuSPARSE Format Conversion Reference
  {"cusparseSbsr2csr",                                  {"hipsparseSbsr2csr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDbsr2csr",                                  {"hipsparseDbsr2csr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCbsr2csr",                                  {"hipsparseCbsr2csr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZbsr2csr",                                  {"hipsparseZbsr2csr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseSgebsr2gebsc_bufferSize",                   {"hipsparseSgebsr2gebsc_bufferSize",                   "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseSgebsr2gebsc_bufferSizeExt",                {"hipsparseSgebsr2gebsc_bufferSizeExt",                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseDgebsr2gebsc_bufferSize",                   {"hipsparseDgebsr2gebsc_bufferSize",                   "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDgebsr2gebsc_bufferSizeExt",                {"hipsparseDgebsr2gebsc_bufferSizeExt",                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseCgebsr2gebsc_bufferSize",                   {"hipsparseCgebsr2gebsc_bufferSize",                   "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCgebsr2gebsc_bufferSizeExt",                {"hipsparseCgebsr2gebsc_bufferSizeExt",                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseZgebsr2gebsc_bufferSize",                   {"hipsparseZgebsr2gebsc_bufferSize",                   "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZgebsr2gebsc_bufferSizeExt",                {"hipsparseZgebsr2gebsc_bufferSizeExt",                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},

  {"cusparseSgebsr2gebsc",                              {"hipsparseSgebsr2gebsc",                              "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDgebsr2gebsc",                              {"hipsparseDgebsr2gebsc",                              "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCgebsr2gebsc",                              {"hipsparseCgebsr2gebsc",                              "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZgebsr2gebsc",                              {"hipsparseZgebsr2gebsc",                              "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseSgebsr2gebsr_bufferSize",                   {"hipsparseSgebsr2gebsr_bufferSize",                   "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseSgebsr2gebsr_bufferSizeExt",                {"hipsparseSgebsr2gebsr_bufferSizeExt",                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseDgebsr2gebsr_bufferSize",                   {"hipsparseDgebsr2gebsr_bufferSize",                   "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDgebsr2gebsr_bufferSizeExt",                {"hipsparseDgebsr2gebsr_bufferSizeExt",                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseCgebsr2gebsr_bufferSize",                   {"hipsparseCgebsr2gebsr_bufferSize",                   "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCgebsr2gebsr_bufferSizeExt",                {"hipsparseCgebsr2gebsr_bufferSizeExt",                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseZgebsr2gebsr_bufferSize",                   {"hipsparseZgebsr2gebsr_bufferSize",                   "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZgebsr2gebsr_bufferSizeExt",                {"hipsparseZgebsr2gebsr_bufferSizeExt",                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},

  {"cusparseXgebsr2csr",                                {"hipsparseXgebsr2csr",                                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSgebsr2csr",                                {"hipsparseSgebsr2csr",                                "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDgebsr2csr",                                {"hipsparseDgebsr2csr",                                "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCgebsr2csr",                                {"hipsparseCgebsr2csr",                                "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZgebsr2csr",                                {"hipsparseZgebsr2csr",                                "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseXgebsr2gebsrNnz",                           {"hipsparseXgebsr2gebsrNnz",                           "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseSgebsr2gebsr",                              {"hipsparseSgebsr2gebsr",                              "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDgebsr2gebsr",                              {"hipsparseDgebsr2gebsr",                              "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCgebsr2gebsr",                              {"hipsparseCgebsr2gebsr",                              "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZgebsr2gebsr",                              {"hipsparseZgebsr2gebsr",                              "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseScsr2gebsr_bufferSize",                     {"hipsparseScsr2gebsr_bufferSize",                     "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseScsr2gebsr_bufferSizeExt",                  {"hipsparseScsr2gebsr_bufferSizeExt",                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseDcsr2gebsr_bufferSize",                     {"hipsparseDcsr2gebsr_bufferSize",                     "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDcsr2gebsr_bufferSizeExt",                  {"hipsparseDcsr2gebsr_bufferSizeExt",                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseCcsr2gebsr_bufferSize",                     {"hipsparseCcsr2gebsr_bufferSize",                     "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCcsr2gebsr_bufferSizeExt",                  {"hipsparseCcsr2gebsr_bufferSizeExt",                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseZcsr2gebsr_bufferSize",                     {"hipsparseZcsr2gebsr_bufferSize",                     "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZcsr2gebsr_bufferSizeExt",                  {"hipsparseZcsr2gebsr_bufferSizeExt",                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},

  {"cusparseXcsr2gebsrNnz",                             {"hipsparseXcsr2gebsrNnz",                             "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseScsr2gebsr",                                {"hipsparseScsr2gebsr",                                "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDcsr2gebsr",                                {"hipsparseDcsr2gebsr",                                "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCcsr2gebsr",                                {"hipsparseCcsr2gebsr",                                "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZcsr2gebsr",                                {"hipsparseZcsr2gebsr",                                "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseXcoo2csr",                                  {"hipsparseXcoo2csr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseScsc2dense",                                {"hipsparseScsc2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseDcsc2dense",                                {"hipsparseDcsc2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseCcsc2dense",                                {"hipsparseCcsc2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseZcsc2dense",                                {"hipsparseZcsc2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},

  {"cusparseScsc2hyb",                                  {"hipsparseScsc2hyb",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDcsc2hyb",                                  {"hipsparseDcsc2hyb",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCcsc2hyb",                                  {"hipsparseCcsc2hyb",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZcsc2hyb",                                  {"hipsparseZcsc2hyb",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseXcsr2bsrNnz",                               {"hipsparseXcsr2bsrNnz",                               "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseScsr2bsr",                                  {"hipsparseScsr2bsr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDcsr2bsr",                                  {"hipsparseDcsr2bsr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCcsr2bsr",                                  {"hipsparseCcsr2bsr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZcsr2bsr",                                  {"hipsparseZcsr2bsr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseXcsr2coo",                                  {"hipsparseXcsr2coo",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseScsr2csc",                                  {"hipsparseScsr2csc",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},
  {"cusparseDcsr2csc",                                  {"hipsparseDcsr2csc",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},
  {"cusparseCcsr2csc",                                  {"hipsparseCcsr2csc",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},
  {"cusparseZcsr2csc",                                  {"hipsparseZcsr2csc",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},

  {"cusparseCsr2cscEx",                                 {"hipsparseCsr2cscEx",                                 "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCsr2cscEx2",                                {"hipsparseCsr2cscEx2",                                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseCsr2cscEx2_bufferSize",                     {"hipsparseCsr2cscEx2_bufferSize",                     "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},

  {"cusparseScsr2dense",                                {"hipsparseScsr2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseDcsr2dense",                                {"hipsparseDcsr2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseCcsr2dense",                                {"hipsparseCcsr2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseZcsr2dense",                                {"hipsparseZcsr2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},

  {"cusparseScsr2csr_compress",                         {"hipsparseScsr2csr_compress",                         "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDcsr2csr_compress",                         {"hipsparseDcsr2csr_compress",                         "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCcsr2csr_compress",                         {"hipsparseCcsr2csr_compress",                         "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZcsr2csr_compress",                         {"hipsparseZcsr2csr_compress",                         "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseScsr2hyb",                                  {"hipsparseScsr2hyb",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},
  {"cusparseDcsr2hyb",                                  {"hipsparseDcsr2hyb",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},
  {"cusparseCcsr2hyb",                                  {"hipsparseCcsr2hyb",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},
  {"cusparseZcsr2hyb",                                  {"hipsparseZcsr2hyb",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},

  {"cusparseSdense2csc",                                {"hipsparseSdense2csc",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseDdense2csc",                                {"hipsparseDdense2csc",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseCdense2csc",                                {"hipsparseCdense2csc",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseZdense2csc",                                {"hipsparseZdense2csc",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},

  {"cusparseSdense2csr",                                {"hipsparseSdense2csr",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseDdense2csr",                                {"hipsparseDdense2csr",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseCdense2csr",                                {"hipsparseCdense2csr",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},
  {"cusparseZdense2csr",                                {"hipsparseZdense2csr",                                "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED}},

  {"cusparseSdense2hyb",                                {"hipsparseSdense2hyb",                                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDdense2hyb",                                {"hipsparseDdense2hyb",                                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseCdense2hyb",                                {"hipsparseCdense2hyb",                                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZdense2hyb",                                {"hipsparseZdense2hyb",                                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseShyb2csc",                                  {"hipsparseShyb2csc",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDhyb2csc",                                  {"hipsparseDhyb2csc",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseChyb2csc",                                  {"hipsparseChyb2csc",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZhyb2csc",                                  {"hipsparseZhyb2csc",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseShyb2csr",                                  {"hipsparseShyb2csr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},
  {"cusparseDhyb2csr",                                  {"hipsparseDhyb2csr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},
  {"cusparseChyb2csr",                                  {"hipsparseChyb2csr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},
  {"cusparseZhyb2csr",                                  {"hipsparseZhyb2csr",                                  "", CONV_LIB_FUNC, API_SPARSE, 13, DEPRECATED | REMOVED}},

  {"cusparseShyb2dense",                                {"hipsparseShyb2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseDhyb2dense",                                {"hipsparseDhyb2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseChyb2dense",                                {"hipsparseChyb2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},
  {"cusparseZhyb2dense",                                {"hipsparseZhyb2dense",                                "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED | DEPRECATED | REMOVED}},

  {"cusparseSnnz",                                      {"hipsparseSnnz",                                      "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDnnz",                                      {"hipsparseDnnz",                                      "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCnnz",                                      {"hipsparseCnnz",                                      "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZnnz",                                      {"hipsparseZnnz",                                      "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseCreateIdentityPermutation",                 {"hipsparseCreateIdentityPermutation",                 "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseXcoosort_bufferSizeExt",                    {"hipsparseXcoosort_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseXcoosortByRow",                             {"hipsparseXcoosortByRow",                             "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseXcoosortByColumn",                          {"hipsparseXcoosortByColumn",                          "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseXcsrsort_bufferSizeExt",                    {"hipsparseXcsrsort_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseXcsrsort",                                  {"hipsparseXcsrsort",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseXcscsort_bufferSizeExt",                    {"hipsparseXcscsort_bufferSizeExt",                    "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseXcscsort",                                  {"hipsparseXcscsort",                                  "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseCreateCsru2csrInfo",                        {"hipsparseCreateCsru2csrInfo",                        "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseDestroyCsru2csrInfo",                       {"hipsparseDestroyCsru2csrInfo",                       "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},

  {"cusparseScsru2csr_bufferSizeExt",                   {"hipsparseScsru2csr_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseDcsru2csr_bufferSizeExt",                   {"hipsparseDcsru2csr_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseCcsru2csr_bufferSizeExt",                   {"hipsparseCcsru2csr_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseZcsru2csr_bufferSizeExt",                   {"hipsparseZcsru2csr_bufferSizeExt",                   "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},

  {"cusparseScsr2csru",                                 {"hipsparseScsr2csru",                                 "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseDcsr2csru",                                 {"hipsparseDcsr2csru",                                 "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseCcsr2csru",                                 {"hipsparseCcsr2csru",                                 "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseZcsr2csru",                                 {"hipsparseZcsr2csru",                                 "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},

  {"cusparseHpruneDense2csr",                           {"hipsparseHpruneDense2csr",                           "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneDense2csr",                           {"hipsparseSpruneDense2csr",                           "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneDense2csr",                           {"hipsparseDpruneDense2csr",                           "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneDense2csr_bufferSizeExt",             {"hipsparseHpruneDense2csr_bufferSizeExt",             "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneDense2csr_bufferSizeExt",             {"hipsparseSpruneDense2csr_bufferSizeExt",             "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneDense2csr_bufferSizeExt",             {"hipsparseDpruneDense2csr_bufferSizeExt",             "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneDense2csrNnz",                        {"hipsparseHpruneDense2csrNnz",                        "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneDense2csrNnz",                        {"hipsparseSpruneDense2csrNnz",                        "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneDense2csrNnz",                        {"hipsparseDpruneDense2csrNnz",                        "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneCsr2csr",                             {"hipsparseHpruneCsr2csr",                             "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneCsr2csr",                             {"hipsparseSpruneCsr2csr",                             "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneCsr2csr",                             {"hipsparseDpruneCsr2csr",                             "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneCsr2csr_bufferSizeExt",               {"hipsparseHpruneCsr2csr_bufferSizeExt",               "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneCsr2csr_bufferSizeExt",               {"hipsparseSpruneCsr2csr_bufferSizeExt",               "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneCsr2csr_bufferSizeExt",               {"hipsparseDpruneCsr2csr_bufferSizeExt",               "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneCsr2csrNnz",                          {"hipsparseHpruneCsr2csrNnz",                          "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneCsr2csrNnz",                          {"hipsparseSpruneCsr2csrNnz",                          "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneCsr2csrNnz",                          {"hipsparseDpruneCsr2csrNnz",                          "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneDense2csrByPercentage",               {"hipsparseHpruneDense2csrByPercentage",               "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneDense2csrByPercentage",               {"hipsparseSpruneDense2csrByPercentage",               "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneDense2csrByPercentage",               {"hipsparseDpruneDense2csrByPercentage",               "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneDense2csrByPercentage_bufferSizeExt", {"hipsparseHpruneDense2csrByPercentage_bufferSizeExt", "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneDense2csrByPercentage_bufferSizeExt", {"hipsparseSpruneDense2csrByPercentage_bufferSizeExt", "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneDense2csrByPercentage_bufferSizeExt", {"hipsparseDpruneDense2csrByPercentage_bufferSizeExt", "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneDense2csrNnzByPercentage",            {"hipsparseHpruneDense2csrNnzByPercentage",            "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneDense2csrNnzByPercentage",            {"hipsparseSpruneDense2csrNnzByPercentage",            "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneDense2csrNnzByPercentage",            {"hipsparseDpruneDense2csrNnzByPercentage",            "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneCsr2csrByPercentage",                 {"hipsparseHpruneCsr2csrByPercentage",                 "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneCsr2csrByPercentage",                 {"hipsparseSpruneCsr2csrByPercentage",                 "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneCsr2csrByPercentage",                 {"hipsparseDpruneCsr2csrByPercentage",                 "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneCsr2csrByPercentage_bufferSizeExt",   {"hipsparseHpruneCsr2csrByPercentage_bufferSizeExt",   "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneCsr2csrByPercentage_bufferSizeExt",   {"hipsparseSpruneCsr2csrByPercentage_bufferSizeExt",   "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneCsr2csrByPercentage_bufferSizeExt",   {"hipsparseDpruneCsr2csrByPercentage_bufferSizeExt",   "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseHpruneCsr2csrNnzByPercentage",              {"hipsparseHpruneCsr2csrNnzByPercentage",              "", CONV_LIB_FUNC, API_SPARSE, 13, HIP_UNSUPPORTED}},
  {"cusparseSpruneCsr2csrNnzByPercentage",              {"hipsparseSpruneCsr2csrNnzByPercentage",              "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDpruneCsr2csrNnzByPercentage",              {"hipsparseDpruneCsr2csrNnzByPercentage",              "", CONV_LIB_FUNC, API_SPARSE, 13}},

  {"cusparseSnnz_compress",                             {"hipsparseSnnz_compress",                             "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseDnnz_compress",                             {"hipsparseDnnz_compress",                             "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseCnnz_compress",                             {"hipsparseCnnz_compress",                             "", CONV_LIB_FUNC, API_SPARSE, 13}},
  {"cusparseZnnz_compress",                             {"hipsparseZnnz_compress",                             "", CONV_LIB_FUNC, API_SPARSE, 13}},

  // 14. cuSPARSE Generic API Reference
  // Generic Sparse API helper functions
  // Sparse Matrix descriptor
  {"cusparseCreateCoo",                                 {"hipsparseCreateCoo",                                 "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCreateCooAoS",                              {"hipsparseCreateCooAoS",                              "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCreateCsr",                                 {"hipsparseCreateCsr",                                 "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCreateCsc",                                 {"hipsparseCreateCsc",                                 "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDestroySpMat",                              {"hipsparseDestroySpMat",                              "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCooGet",                                    {"hipsparseCooGet",                                    "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCooAoSGet",                                 {"hipsparseCooAoSGet",                                 "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCooSetStridedBatch",                        {"hipsparseCooSetStridedBatch",                        "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCsrGet",                                    {"hipsparseCsrGet",                                    "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCsrSetPointers",                            {"hipsparseCsrSetPointers",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCscSetPointers",                            {"hipsparseCscSetPointers",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCooSetPointers",                            {"hipsparseCooSetPointers",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseCsrSetStridedBatch",                        {"hipsparseCsrSetStridedBatch",                        "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMatGetFormat",                            {"hipsparseSpMatGetFormat",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMatGetIndexBase",                         {"hipsparseSpMatGetIndexBase",                         "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMatGetValues",                            {"hipsparseSpMatGetValues",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMatSetValues",                            {"hipsparseSpMatSetValues",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMatGetStridedBatch",                      {"hipsparseSpMatGetStridedBatch",                      "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMatSetStridedBatch",                      {"hipsparseSpMatSetStridedBatch",                      "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMatSetNumBatches",                        {"hipsparseSpMatSetNumBatches",                        "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMatGetNumBatches",                        {"hipsparseSpMatGetNumBatches",                        "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMatGetSize",                              {"hipsparseSpMatGetSize",                              "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  // Sparse Vector descriptor
  {"cusparseCreateSpVec",                               {"hipsparseCreateSpVec",                               "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDestroySpVec",                              {"hipsparseDestroySpVec",                              "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpVecGet",                                  {"hipsparseSpVecGet",                                  "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpVecGetIndexBase",                         {"hipsparseSpVecGetIndexBase",                         "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpVecGetValues",                            {"hipsparseSpVecGetValues",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpVecSetValues",                            {"hipsparseSpVecSetValues",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},

  // Generic Dense API helper functions
  // Dense Matrix descriptor
  {"cusparseCreateDnMat",                               {"hipsparseCreateDnMat",                               "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDestroyDnMat",                              {"hipsparseDestroyDnMat",                              "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDnMatGet",                                  {"hipsparseDnMatGet",                                  "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDnMatGetValues",                            {"hipsparseDnMatGetValues",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDnMatSetValues",                            {"hipsparseDnMatSetValues",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDnMatSetStridedBatch",                      {"hipsparseDnMatSetStridedBatch",                      "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDnMatGetStridedBatch",                      {"hipsparseDnMatGetStridedBatch",                      "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  // Dense Vector descriptor
  {"cusparseCreateDnVec",                               {"hipsparseCreateDnVec",                               "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDestroyDnVec",                              {"hipsparseDestroyDnVec",                              "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDnVecGet",                                  {"hipsparseDnVecGet",                                  "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDnVecGetValues",                            {"hipsparseDnVecGetValues",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDnVecSetValues",                            {"hipsparseDnVecSetValues",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},

  {"cusparseSpGEMM_createDescr",                        {"hipsparseSpGEMM_createDescr",                        "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpGEMM_destroyDescr",                       {"hipsparseSpGEMM_destroyDescr",                       "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpGEMM_workEstimation",                     {"hipsparseSpGEMM_workEstimation",                     "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpGEMM_compute",                            {"hipsparseSpGEMM_compute",                            "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpGEMM_copy",                               {"hipsparseSpGEMM_copy",                               "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},

  // Sparse Matrix * Matrix Multiplication
  {"cusparseSpMM",                                      {"hipsparseSpMM",                                      "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMM_bufferSize",                           {"hipsparseSpMM_bufferSize",                           "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},

  // Sparse Matrix * Matrix Pattern-constrained Multiplication
  {"cusparseConstrainedGeMM",                           {"hipsparseConstrainedGeMM",                           "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseConstrainedGeMM_bufferSize",                {"hipsparseConstrainedGeMM_bufferSize",                "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},

  // Sparse Vector * Vector Operations
  {"cusparseSpVV",                                      {"hipsparseSpVV",                                      "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpVV_bufferSize",                           {"hipsparseSpVV_bufferSize",                           "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},

  {"cusparseAxpby",                                     {"hipsparseAxpby",                                     "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseGather",                                    {"hipsparseGather",                                    "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseScatter",                                   {"hipsparseScatter",                                   "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseRot",                                       {"hipsparseRot",                                       "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},

  // Sparse Matrix * Vector Multiplication
  {"cusparseSpMV",                                      {"hipsparseSpMV",                                      "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSpMV_bufferSize",                           {"hipsparseSpMV_bufferSize",                           "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},

  {"cusparseSparseToDense",                             {"hipsparseSparseToDense",                             "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseSparseToDense_bufferSize",                  {"hipsparseSparseToDense_bufferSize",                  "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDenseToSparse_bufferSize",                  {"hipsparseDenseToSparse_bufferSize",                  "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDenseToSparse_analysis",                    {"hipsparseDenseToSparse_analysis",                    "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
  {"cusparseDenseToSparse_convert",                     {"hipsparseDenseToSparse_convert",                     "", CONV_LIB_FUNC, API_SPARSE, 14, HIP_UNSUPPORTED}},
};

const std::map<llvm::StringRef, cudaAPIversions> CUDA_SPARSE_FUNCTION_VER_MAP {
  {"cusparseCreateCsrgemm2Info",                        {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseCreateCsrsm2Info",                          {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseCreateHybMat",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCreatePruneInfo",                           {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseCreateSolveAnalysisInfo",                   {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDestroyCsrgemm2Info",                       {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseDestroyCsrsm2Info",                         {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseDestroyHybMat",                             {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDestroyPruneInfo",                          {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDestroySolveAnalysisInfo",                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseGetLevelInfo",                              {CUDA_0,   CUDA_0,   CUDA_110}},
  {"cusparseSdoti",                                     {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDdoti",                                     {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCdoti",                                     {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZdoti",                                     {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCdotci",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZdotci",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseScsrmv",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsrmv",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsrmv",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsrmv",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCsrmvEx",                                   {CUDA_80,  CUDA_0,   CUDA_0  }},
  {"cusparseCsrmvEx_bufferSize",                        {CUDA_80,  CUDA_0,   CUDA_0  }},
  {"cusparseScsrmv_mp",                                 {CUDA_80,  CUDA_102, CUDA_110}},
  {"cusparseDcsrmv_mp",                                 {CUDA_80,  CUDA_102, CUDA_110}},
  {"cusparseCcsrmv_mp",                                 {CUDA_80,  CUDA_102, CUDA_110}},
  {"cusparseZcsrmv_mp",                                 {CUDA_80,  CUDA_102, CUDA_110}},
  {"cusparseSgemvi",                                    {CUDA_75,  CUDA_0,   CUDA_0  }},
  {"cusparseDgemvi",                                    {CUDA_75,  CUDA_0,   CUDA_0  }},
  {"cusparseCgemvi",                                    {CUDA_75,  CUDA_0,   CUDA_0  }},
  {"cusparseZgemvi",                                    {CUDA_75,  CUDA_0,   CUDA_0  }},
  {"cusparseSgemvi_bufferSize",                         {CUDA_75,  CUDA_0,   CUDA_0  }},
  {"cusparseDgemvi_bufferSize",                         {CUDA_75,  CUDA_0,   CUDA_0  }},
  {"cusparseCgemvi_bufferSize",                         {CUDA_75,  CUDA_0,   CUDA_0  }},
  {"cusparseZgemvi_bufferSize",                         {CUDA_75,  CUDA_0,   CUDA_0  }},
  {"cusparseScsrsv_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsrsv_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsrsv_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsrsv_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseScsrsv_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsrsv_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsrsv_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsrsv_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCsrsv_analysisEx",                          {CUDA_80,  CUDA_102, CUDA_110}},
  {"cusparseCsrsv_solveEx",                             {CUDA_80,  CUDA_102, CUDA_110}},
  {"cusparseShybmv",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDhybmv",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseChybmv",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZhybmv",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseShybsv_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDhybsv_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseChybsv_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZhybsv_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseShybsv_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDhybsv_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseChybsv_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZhybsv_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseScsrmm",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsrmm",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsrmm",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsrmm",                                    {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseScsrmm2",                                   {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsrmm2",                                   {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsrmm2",                                   {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsrmm2",                                   {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseScsrsm_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsrsm_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsrsm_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsrsm_analysis",                           {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseScsrsm_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsrsm_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsrsm_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsrsm_solve",                              {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseScsrsm2_bufferSizeExt",                     {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseDcsrsm2_bufferSizeExt",                     {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseCcsrsm2_bufferSizeExt",                     {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseZcsrsm2_bufferSizeExt",                     {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseScsrsm2_analysis",                          {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseDcsrsm2_analysis",                          {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseCcsrsm2_analysis",                          {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseZcsrsm2_analysis",                          {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseScsrsm2_solve",                             {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseDcsrsm2_solve",                             {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseCcsrsm2_solve",                             {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseZcsrsm2_solve",                             {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseXcsrsm2_zeroPivot",                         {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseSgemmi",                                    {CUDA_80,  CUDA_110, CUDA_0  }},
  {"cusparseDgemmi",                                    {CUDA_80,  CUDA_110, CUDA_0  }},
  {"cusparseCgemmi",                                    {CUDA_80,  CUDA_110, CUDA_0  }},
  {"cusparseZgemmi",                                    {CUDA_80,  CUDA_110, CUDA_0  }},
  {"cusparseScsrgeam",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsrgeam",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsrgeam",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsrgeam",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseXcsrgeamNnz",                               {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseScsrgeam2",                                 {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseDcsrgeam2",                                 {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseCcsrgeam2",                                 {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseZcsrgeam2",                                 {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseXcsrgeam2Nnz",                              {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseScsrgeam2_bufferSizeExt",                   {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseDcsrgeam2_bufferSizeExt",                   {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseCcsrgeam2_bufferSizeExt",                   {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseZcsrgeam2_bufferSizeExt",                   {CUDA_100, CUDA_0,   CUDA_0  }},
  {"cusparseScsrgemm",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsrgemm",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsrgemm",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsrgemm",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseXcsrgemmNnz",                               {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseXcsrgemmNnz",                               {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseScsrgemm2",                                 {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseDcsrgemm2",                                 {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseCcsrgemm2",                                 {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseZcsrgemm2",                                 {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseXcsrgemm2Nnz",                              {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseScsrgemm2_bufferSizeExt",                   {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseDcsrgemm2_bufferSizeExt",                   {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseCcsrgemm2_bufferSizeExt",                   {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseZcsrgemm2_bufferSizeExt",                   {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseScsric0",                                   {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsric0",                                   {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsric0",                                   {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsric0",                                   {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseScsrilu0",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsrilu0",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsrilu0",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsrilu0",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCsrilu0Ex",                                 {CUDA_80,  CUDA_102, CUDA_110}},
  {"cusparseSgtsv",                                     {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDgtsv",                                     {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCgtsv",                                     {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZgtsv",                                     {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseSgtsv_nopivot",                             {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDgtsv_nopivot",                             {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCgtsv_nopivot",                             {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZgtsv_nopivot",                             {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseSgtsv2_bufferSizeExt",                      {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDgtsv2_bufferSizeExt",                      {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseCgtsv2_bufferSizeExt",                      {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseZgtsv2_bufferSizeExt",                      {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsv2",                                    {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDgtsv2",                                    {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseCgtsv2",                                    {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseZgtsv2",                                    {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsv2_nopivot_bufferSizeExt",              {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDgtsv2_nopivot_bufferSizeExt",              {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseCgtsv2_nopivot_bufferSizeExt",              {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseZgtsv2_nopivot_bufferSizeExt",              {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsv2_nopivot",                            {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDgtsv2_nopivot",                            {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseCgtsv2_nopivot",                            {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseZgtsv2_nopivot",                            {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsvStridedBatch",                         {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDgtsvStridedBatch",                         {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCgtsvStridedBatch",                         {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZgtsvStridedBatch",                         {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseSgtsv2StridedBatch_bufferSizeExt",          {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsvDStridedBatch_bufferSizeExt",          {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsvCStridedBatch_bufferSizeExt",          {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsvZStridedBatch_bufferSizeExt",          {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsv2StridedBatch",                        {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsv2DtridedBatch",                        {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsv2CtridedBatch",                        {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsv2ZtridedBatch",                        {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsvInterleavedBatch_bufferSizeExt",       {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseDgtsvInterleavedBatch_bufferSizeExt",       {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseCgtsvInterleavedBatch_bufferSizeExt",       {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseZgtsvInterleavedBatch_bufferSizeExt",       {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseSgtsvInterleavedBatch",                     {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseDgtsvInterleavedBatch",                     {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseCgtsvInterleavedBatch",                     {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseZgtsvInterleavedBatch",                     {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseSgpsvInterleavedBatch_bufferSizeExt",       {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseDgpsvInterleavedBatch_bufferSizeExt",       {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseCgpsvInterleavedBatch_bufferSizeExt",       {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseZgpsvInterleavedBatch_bufferSizeExt",       {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseSgpsvInterleavedBatch",                     {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseDgpsvInterleavedBatch",                     {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseCgpsvInterleavedBatch",                     {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseZgpsvInterleavedBatch",                     {CUDA_92,  CUDA_0,   CUDA_0  }},
  {"cusparseScsc2hyb",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsc2hyb",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsc2hyb",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsc2hyb",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCsr2cscEx",                                 {CUDA_80,  CUDA_102, CUDA_110}},
  {"cusparseCsr2cscEx2",                                {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseCsr2cscEx2_bufferSize",                     {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseScsr2csr_compress",                         {CUDA_80,  CUDA_0,   CUDA_0  }},
  {"cusparseDcsr2csr_compress",                         {CUDA_80,  CUDA_0,   CUDA_0  }},
  {"cusparseCcsr2csr_compress",                         {CUDA_80,  CUDA_0,   CUDA_0  }},
  {"cusparseZcsr2csr_compress",                         {CUDA_80,  CUDA_0,   CUDA_0  }},
  {"cusparseScsr2hyb",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsr2hyb",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsr2hyb",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsr2hyb",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseSdense2hyb",                                {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDdense2hyb",                                {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCdense2hyb",                                {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZdense2hyb",                                {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseShyb2csc",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDhyb2csc",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseChyb2csc",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZhyb2csc",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseShyb2csr",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDhyb2csr",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseChyb2csr",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZhyb2csr",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseShyb2dense",                                {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDhyb2dense",                                {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseChyb2dense",                                {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZhyb2dense",                                {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseHpruneDense2csr",                           {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneDense2csr",                           {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneDense2csr",                           {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneDense2csr_bufferSizeExt",             {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneDense2csr_bufferSizeExt",             {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneDense2csr_bufferSizeExt",             {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneDense2csrNnz",                        {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneDense2csrNnz",                        {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneDense2csrNnz",                        {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneCsr2csr",                             {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneCsr2csr",                             {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneCsr2csr",                             {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneCsr2csr_bufferSizeExt",               {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneCsr2csr_bufferSizeExt",               {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneCsr2csr_bufferSizeExt",               {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneCsr2csrNnz",                          {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneCsr2csrNnz",                          {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneCsr2csrNnz",                          {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneDense2csrByPercentage",               {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneDense2csrByPercentage",               {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneDense2csrByPercentage",               {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneDense2csrByPercentage_bufferSizeExt", {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneDense2csrByPercentage_bufferSizeExt", {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneDense2csrByPercentage_bufferSizeExt", {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneDense2csrNnzByPercentage",            {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneDense2csrNnzByPercentage",            {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneDense2csrNnzByPercentage",            {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneCsr2csrByPercentage",                 {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneCsr2csrByPercentage",                 {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneCsr2csrByPercentage",                 {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneCsr2csrByPercentage_bufferSizeExt",   {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneCsr2csrByPercentage_bufferSizeExt",   {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneCsr2csrByPercentage_bufferSizeExt",   {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseHpruneCsr2csrNnzByPercentage",              {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSpruneCsr2csrNnzByPercentage",              {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseDpruneCsr2csrNnzByPercentage",              {CUDA_90,  CUDA_0,   CUDA_0  }},
  {"cusparseSnnz_compress",                             {CUDA_80,  CUDA_0,   CUDA_0  }},
  {"cusparseDnnz_compress",                             {CUDA_80,  CUDA_0,   CUDA_0  }},
  {"cusparseCnnz_compress",                             {CUDA_80,  CUDA_0,   CUDA_0  }},
  {"cusparseZnnz_compress",                             {CUDA_80,  CUDA_0,   CUDA_0  }},
  {"cusparseCreateCoo",                                 {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseCreateCooAoS",                              {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseCreateCsr",                                 {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseDestroySpMat",                              {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseCooGet",                                    {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseCooAoSGet",                                 {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseCsrGet",                                    {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpMatGetFormat",                            {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseSpMatGetIndexBase",                         {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseSpMatGetValues",                            {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpMatSetValues",                            {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpMatGetStridedBatch",                      {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpMatSetStridedBatch",                      {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpMatSetNumBatches",                        {CUDA_101, CUDA_0,   CUDA_102}},
  {"cusparseSpMatGetNumBatches",                        {CUDA_101, CUDA_0,   CUDA_102}},
  {"cusparseCreateSpVec",                               {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseDestroySpVec",                              {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpVecGet",                                  {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpVecGetIndexBase",                         {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpVecGetValues",                            {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpVecSetValues",                            {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseCreateDnMat",                               {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseDestroyDnMat",                              {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseDnMatGet",                                  {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseDnMatGetValues",                            {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseDnMatSetValues",                            {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseDnMatSetStridedBatch",                      {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseDnMatGetStridedBatch",                      {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseCreateDnVec",                               {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseDestroyDnVec",                              {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseDnVecGet",                                  {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseDnVecGetValues",                            {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseDnVecSetValues",                            {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpMM",                                      {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseSpMM_bufferSize",                           {CUDA_101, CUDA_0,   CUDA_0  }},
  {"cusparseSpVV",                                      {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpVV_bufferSize",                           {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpMV",                                      {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSpMV_bufferSize",                           {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSaxpyi",                                    {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseDaxpyi",                                    {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseCaxpyi",                                    {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseZaxpyi",                                    {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseSgthr",                                     {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseDgthr",                                     {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseCgthr",                                     {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseZgthr",                                     {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseSgthrz",                                    {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseDgthrz",                                    {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseCgthrz",                                    {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseZgthrz",                                    {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseSsctr",                                     {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseDsctr",                                     {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseCsctr",                                     {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseZsctr",                                     {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseSroti",                                     {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseDroti",                                     {CUDA_0,   CUDA_110, CUDA_0  }},
  {"cusparseScsr2csc",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseDcsr2csc",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseCcsr2csc",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseZcsr2csc",                                  {CUDA_0,   CUDA_102, CUDA_110}},
  {"cusparseSpMatGetSize",                              {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseCooSetStridedBatch",                        {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseCsrSetStridedBatch",                        {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseAxpby",                                     {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseGather",                                    {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseScatter",                                   {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseRot",                                       {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseSpGEMM_createDescr",                        {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseSpGEMM_destroyDescr",                       {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseSpGEMM_compute",                            {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseSpGEMM_copy",                               {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseConstrainedGeMM",                           {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseConstrainedGeMM_bufferSize",                {CUDA_102, CUDA_0,   CUDA_0  }},
  {"cusparseSdense2csr",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseDdense2csr",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseCdense2csr",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseZdense2csr",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseScsr2dense",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseDcsr2dense",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseCcsr2dense",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseZcsr2dense",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseSdense2csc",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseDdense2csc",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseCdense2csc",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseZdense2csc",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseScsc2dense",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseDcsc2dense",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseCcsc2dense",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseZcsc2dense",                                {CUDA_0,   CUDA_111, CUDA_0  }},
  {"cusparseCreateCsc",                                 {CUDA_111, CUDA_0,   CUDA_0  }},
  {"cusparseCsrSetPointers",                            {CUDA_110, CUDA_0,   CUDA_0  }},
  {"cusparseCscSetPointers",                            {CUDA_111, CUDA_0,   CUDA_0  }},
  {"cusparseCooSetPointers",                            {CUDA_111, CUDA_0,   CUDA_0  }},
  {"cusparseSparseToDense_bufferSize",                  {CUDA_111, CUDA_0,   CUDA_0  }},
  {"cusparseSparseToDense",                             {CUDA_111, CUDA_0,   CUDA_0  }},
  {"cusparseDenseToSparse_bufferSize",                  {CUDA_111, CUDA_0,   CUDA_0  }},
  {"cusparseDenseToSparse_analysis",                    {CUDA_111, CUDA_0,   CUDA_0  }},
  {"cusparseDenseToSparse_convert",                     {CUDA_111, CUDA_0,   CUDA_0  }},
};

const std::map<llvm::StringRef, hipAPIversions> HIP_SPARSE_FUNCTION_VER_MAP {
};

const std::map<unsigned int, llvm::StringRef> CUDA_SPARSE_API_SECTION_MAP {
  {4, "CUSPARSE Types References"},
  {5, "CUSPARSE Management Function Reference"},
  {6, "CUSPARSE Helper Function Reference"},
  {7, "CUSPARSE Level 1 Function Reference"},
  {8, "CUSPARSE Level 2 Function Reference"},
  {9, "CUSPARSE Level 3 Function Reference"},
  {10, "CUSPARSE Extra Function Reference"},
  {11, "CUSPARSE Preconditioners Reference"},
  {12, "CUSPARSE Reorderings Reference"},
  {13, "CUSPARSE Format Conversion Reference"},
  {14, "CUSPARSE Generic API Reference"},
};
